@@ -201,7 +201,7 @@ static const char *def_extgroup(cmd_parms *cmd, void *dummy,
 	    &authnz_external_module);
 
     apr_table_set( svr->group_path,   keyword, path );
-    apr_table_set( svr->group_method, keyword, DEFAULT_METHOD );
+    apr_table_set( svr->group_method, keyword, method );
 
     return NULL;
 }
@@ -443,8 +443,8 @@ static int exec_external(const char *extpath, const char *extmethod,
 	if (remote_host != NULL)
 	    child_env[i++]= apr_pstrcat(p, ENV_HOST"=", remote_host,NULL);
 
-	if (c->remote_ip)
-	    child_env[i++]= apr_pstrcat(p, ENV_IP"=", c->remote_ip, NULL);
+	if (r->useragent_ip)
+	    child_env[i++]= apr_pstrcat(p, ENV_IP"=", r->useragent_ip, NULL);
 
 	if (r->uri)
 	    child_env[i++]= apr_pstrcat(p, ENV_URI"=", r->uri, NULL);
